# Code2flow CHANGELOG

## [2.2.0] - 2021-06-21
Ruby + PHP support

## [2.1.1] - 2021-06-15
Updates to the CLI that allow code2flow to hypothetically run in Windows

## [2.1.0] - 2021-06-15
Javascript support

## [2.0.1] - 2021-05-30
Add support for constructors to Python

## [2.0.0] - 2021-04-28
Almost complete rewrite / refactor. Update to Python3. Use ASTs

## [0.2] - 2013-06-08
Cleaned up code. Remove comments runs much faster. Test scripts. Template.py implementation file. More to come!

## [0.1] - 2013-05-23
Initial release 
